@@ -8,8 +8,8 @@ from .connection import ConnectionPool
 from .producer import NonBlockingTaskProducer
 from .result import AsyncResult
 
-VERSION = (0, 3, 1)
-__version__ = '.'.join(map(str, VERSION))
+VERSION = (0, 3, 2)
+__version__ = '.'.join(map(str, VERSION)) + '-dev'
 
 
 def setup_nonblocking_producer(celery_app=None, io_loop=None,
@@ -19,7 +19,7 @@ def setup_nonblocking_producer(celery_app=None, io_loop=None,
     io_loop = io_loop or ioloop.IOLoop.instance()
 
     NonBlockingTaskProducer.app = celery_app
-    NonBlockingTaskProducer.conn_pool = ConnectionPool(limit=limit)
+    NonBlockingTaskProducer.conn_pool = ConnectionPool(limit, io_loop)
     NonBlockingTaskProducer.result_cls = result_cls
     if celery_app.conf['BROKER_URL'] and celery_app.conf['BROKER_URL'].startswith('amqp'):
         celery.app.amqp.AMQP.producer_cls = NonBlockingTaskProducer
